@@ -91,8 +91,6 @@ from .opencv import edges
 from .visualizations import hex_to_rgb
 from .visualizations import draw_rectangle
 
-# Time
-from .time import now
 
 # Resize
 from .resize import resize 
@@ -101,32 +99,6 @@ from .resize import center_crop
 # Image 
 from .io import imread
 from .io import imsave
-# # Distance
-# from .distance import distance
-
-# # Convolve
-# from .convolve import daubechies
-# from .convolve import idaubechies
-# from .convolve import find
-# from .convolve import haar
-# from .convolve import ihaar
-# from .convolve import rank_filter
-# from .convolve import mean_filter
-# from .convolve import convolve
-# from .convolve import convolve1d
-# from .convolve import gaussian_filter
-# from .convolve import gaussian_filter1d
-# from .convolve import laplacian_2D
-
-# # Morphology
-# from .morph import cwatershed
-# from .morph import cerode
-# from .morph import erode
-# from .morph import cdilate
-# from .morph import dilate
-# from .morph import get_structuring_elem
-# from .morph import hitmiss
-
 
 # Bringing in configuration variables from globals.py
 from .globals import CROP_CENTRE
@@ -137,15 +109,6 @@ from .globals import CROP_BOTTOM
 from .globals import VALID_URL_NO_EXIST
 from .globals import INVALID_URL_STRING
 
-# except ImportError:
-#     import sys 
-#     _, e, _ = sys.exc_info()
-#     sys.stderr.write(f"""\
-#         Could not import submodules (exact error was: {e}).
-#         There are many reasons for this error the most common one is that you have either not built the packages, built (using `python setup.py build`) or installed them (using `python setup.py install`) and then proceeded to test caer **without changing the current directory**.
-#         Try installing and then changing to another directory before importing caer.
-#         """)
-
 
 def get_caer_version():
     return __version__
@@ -165,7 +128,6 @@ from .io import __all__ as __all_io__
 from .resize import __all__ as __all_resize__
 from .opencv import __all__ as __all_opencv__
 from .preprocess import __all__ as __all_preprocess__
-from .time import __all__ as __all_time__
 from .utilities import __all__ as __all_utilities__
 from .visualizations import __all__ as __all_visualizations__
 
@@ -179,7 +141,7 @@ from .distance import __all__ as __all_distance__
 from .morph import __all__ as __all_morph__
 
 
-__all__ = __all_globals__ + __all_io__ + __all_resize__ + __all_opencv__ + __all_preprocess__ + __all_time__ + __all_utilities__ + __all_visualizations__ + __all_filters__ + __all_distance__ + __all_morph__
+__all__ = __all_globals__ + __all_io__ + __all_resize__ + __all_opencv__ + __all_preprocess__ + __all_utilities__ + __all_visualizations__ + __all_filters__ + __all_distance__ + __all_morph__
 
 __all__ += __all_preprocessing__ 
 __all__ += __all_video__ 
@@ -193,7 +155,6 @@ del __all_io__
 del __all_resize__ 
 del __all_opencv__ 
 del __all_preprocess__ 
-del __all_time__ 
 del __all_utilities__ 
 del __all_visualizations__
 
