@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|__\_
+#  \_____\/_/    \_ \______ |_|  \_
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -208,7 +208,7 @@ def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size
                 print(f'[INFO] {tot_count} files found')
                 if show_size:
                     tot_size = size_image_list + size_video_list
-                    print('[INFO] Total disk size of media files were {:.2f}Mb '.format(tot_size))
+                    print(f'[INFO] Total disk size of media files were {tot_size:.2f}Mb ')
 
             media_files = image_files + video_files
             return media_files
@@ -217,7 +217,7 @@ def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size
             if verbose != 0:
                 print(f'[INFO] {count_image_list} images found')
                 if show_size:
-                    print('[INFO] Total disk size of media files were {:.2f}Mb '.format(size_image_list))
+                    print(f'[INFO] Total disk size of media files were {size_image_list:.2f}Mb ')
 
             return image_files
 
@@ -225,7 +225,7 @@ def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size
             if verbose != 0:
                 print(f'[INFO] {count_video_list} videos found')
                 if show_size:
-                    print('[INFO] Total disk size of videos were {:.2f}Mb '.format(size_video_list))
+                    print(f'[INFO] Total disk size of videos were {size_video_list:.2f}Mb ')
 
             return video_files
         
@@ -295,7 +295,7 @@ def listdir(DIR, include_subdirs=True, use_fullpath=False, show_size=True, verbo
             print(f'[INFO] {count_files} files found')
 
         if show_size:
-            print('[INFO] Total disk size of files were {:.2f}Mb '.format(size_dirs_list))
+            print(f'[INFO] Total disk size of files were {size_dirs_list:.2f}Mb ')
 
     return dirs
 
