@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|__\_
+#  \_____\/_/    \_ \______ |_|  \_
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -108,8 +108,9 @@ def preprocess_from_dir(DIR,
         since = time.time()
         data = npload(destination_filename, allow_pickle=True)
         end = time.time()
+        took = end - since
         print('----------------------------------------------')
-        print('[INFO] Loaded in {:.0f}s from Numpy Files'.format(end-since))
+        print(f'[INFO] Loaded in {took:.0f}s from Numpy Files')
 
         return data
 
@@ -191,14 +192,18 @@ def preprocess_from_dir(DIR,
             end = time.time()
             
             time_elapsed = end-since
-
-            print('[INFO] {} saved! Took {:.0f}m {:.0f}s'.format(destination_filename, time_elapsed // 60, time_elapsed % 60))
+            minu_elapsed = time_elapsed // 60
+            sec_elapsed = time_elapsed % 60
+            print(f'[INFO] {destination_filename} saved! Took {minu_elapsed:.0f}m {sec_elapsed:.0f}s')
 
         #Returns Training Set
         end_preprocess = time.time()
         time_elapsed_preprocess = end_preprocess - since_preprocess
+        minu = time_elapsed_preprocess // 60
+        sec = time_elapsed_preprocess % 60
+
         print('----------------------------------------------')
-        print('[INFO] {} files preprocessed! Took {:.0f}m {:.0f}s'.format(len(data), time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
+        print(f'[INFO] {len(data)} files preprocessed! Took {minu:.0f}m {sec:.0f}s')
 
         if return_classes_flag:
             return data, classes
