@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|__\_
+#  \_____\/_/    \_ \______ |_|  \_
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -117,7 +117,7 @@ def compute_mean_from_dir(DIR, channels, per_channel_subtraction=True):
 
 def compute_mean(data, channels, per_channel_subtraction=True):
     """
-        Computes mean oer channel over the train set and returns a tuple of dimensions=channels
+        Computes mean per channel over the train set and returns a tuple of dimensions=channels
         Train should not be normalized
     """
     if len(data) == 0:
