@@ -3,12 +3,13 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|__\_
+#  \_____\/_/    \_ \______ |_|  \_
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
 
+
 import math
 import time
 import cv2 as cv
@@ -123,20 +124,18 @@ def extract_frames(input_folder,
     
     # Printing stats
     taken = end-start
+    minu = taken // 60
+    sec = taken % 60
     if processed_videos > 1:
-        print('[INFO] {} videos extracted in {:.0f}m {:.0f}s'.format(processed_videos, 
-                                                                    taken // 60,
-                                                                    taken % 60 ))
+        print(f'[INFO] {processed_videos} videos extracted in {minu:.0f}m {sec:.0f}s')
     else:
-        print('[INFO] {} video extracted in {:.0f}m {:.0f}s'.format(processed_videos, 
-                                                                    taken // 60,
-                                                                    taken % 60 ))
+        print(f'[INFO] {processed_videos} video extracted in {minu:.0f}m {sec:.0f}s')
 
     return label_counter
 
 
 def _determine_interval(x):
-    y = '{:.1f}'.format(x)
+    y = '{x:.1f}'
     inde = y.find('.') + 1
     if inde == -1: # if no '.' (if an integer)
         return x
